##
##  mpfr.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2023 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package version
%define       V_base  4.2.1
%define       V_patch 0

#   package information
Name:         mpfr
Summary:      Multiple-Precision Floating-Point Library
URL:          http://www.mpfr.org/
Vendor:       INRIA/LORIA
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        CORE
Group:        Algorithm
License:      LGPL
Version:      %{V_base}.%{V_patch}
Release:      20230825

#   list of sources
Source0:      http://www.mpfr.org/mpfr-current/mpfr-%{V_base}.tar.gz
Patch0:       mpfr.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101
PreReq:       OpenPKG, openpkg >= 20160101
BuildPreReq:  gmp
PreReq:       gmp

%description
    The MPFR library is a C library for multiple-precision
    floating-point computations with exact rounding (also called correct
    rounding). It is based on the GMP multiple-precision library. The
    main goal of MPFR is to provide a library for multiple-precision
    floating-point computation which is both efficient and has
    a well-defined semantics. It copies the good ideas from the
    ANSI/IEEE-754 standard for double-precision floating-point
    arithmetic (53-bit mantissa).

%track
    prog mpfr = {
        version   = %{V_base}
        url       = http://www.mpfr.org/mpfr-current/
        regex     = mpfr-(__VER__)\.tar\.gz
    }
    prog mpfr:patches = {
        version   = %{V_patch}
        url       = http://www.mpfr.org/mpfr-current/
        regex     = patch(\d\d)
    }

%prep
    %setup -q -n mpfr-%{V_base}
    %patch -p0

%build
    CC="%{l_cc}" \
    CFLAGS="%{l_cflags -O}" \
    CPPFLAGS="%{l_cppflags}" \
    LDFLAGS="%{l_ldflags}" \
    MAKEINFO="true" \
    ./configure \
        --prefix=%{l_prefix} \
        --infodir=%{l_prefix}/info \
        --with-gmp=%{l_prefix} \
        --disable-shared
    %{l_make} %{l_mflags -O}

%install
    %{l_make} %{l_mflags} install AM_MAKEFLAGS="DESTDIR=$RPM_BUILD_ROOT"
    strip $RPM_BUILD_ROOT%{l_prefix}/bin/* >/dev/null 2>&1 || true
    rm -rf $RPM_BUILD_ROOT%{l_prefix}/share >/dev/null 2>&1 || true
    rm -f $RPM_BUILD_ROOT%{l_prefix}/info/dir
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT %{l_files_std}

%files -f files

%clean

